Plot from a fitted phylosem model
Arguments
- x
Output from
phylosem- y
Not used
- edge_label
Whether to plot parameter names, estimated values, or estimated values along with stars indicating significance at 0.05, 0.01, or 0.001 levels (based on two-sided Wald tests)
- digits
integer indicating the number of decimal places to be used
- vertices
optional charater vector, listing variables to plot and subsetting edges to only plot those connecting those vertices
- keep_twoheaded
whether to included two-headed arrows
- style
Whether to make a graph using
igraphorggraph- ...
arguments passed to
plot.igraph
Value
Invisibly returns the output from graph_from_data_frame
which was passed to plot.igraph for plotting.